@@ -5,7 +5,7 @@ class Admin():
     user_id: int
     name: str
 
-    def parse(__init__, user_id: int, name: str, **kwargs) -> None:
+    def __init__(self, user_id: int, name: str, **kwargs) -> None:
         self.user_id = user_id
         self.name = name
 
@@ -35,4 +35,4 @@ class Ban():
         self.user_id = user_id
         self.reason = reason
         self.date = date
-        self.admin = Admin(banned_by)
\ No newline at end of file
+        self.admin = Admin(**banned_by)
\ No newline at end of file
